# 웹소켓 페이로드

#### 페이로드 구조

|이름|자료형|설명|
|---|----|-----------|
|op|문자열|페이로드의 이름|
|d|혼합 (대부분 JSON)|페이로드의 데이터|

### 페이로드 전송하기

#### 페이로드 전송 예제

```json
{
    "op": "페이로드 이름",
    "d": {}
}
```

### 페이로드의 오류 반환

#### 페이로드 예외 예제

```json
{
    "op": "페이로드 이름",
    "d": {
        "traceback": "파이썬 예외"
    }
}
```

### HEARTBEAT

```json5
{
    "op": "HEARTBEAT",
    "d": 1596417937 // 타임스탬프
}
```

### GET_STAT

```json5
{
    "op": "GET_STAT"
}
```

### IDENTIFY

```json
{
    "op": "IDENTIFY",
    "d": {
        "user_id": "봇 ID",
        "session_id": "디스코드 연결의 세션 ID"
    }
}
```

### DISCORD_EVENT

```json5
{
    "op": "DISCORD_EVENT",
    "d": {
        // 디스코드 소켓 이벤트
    }
}
```
**`READY`, `RESUME`, `VOICE_STATE_UPDATE`, `VOICE_SERVER_UPDATE` 페이로드만이 필요합니다.**

## 오디오 플레이어

음성 채널에 연결한 이후에만 사용할 수 있습니다.

### setVolume

```json5
{
    "op": "setVolume",
    "d": {
        "guild_id": "오디오 플레이어의 서버 ID",
        "volume": 1 // 0.0~2.0
    }
}
```

### setCrossfade

```json5
{
    "op": "setCrossfade",
    "d": {
        "guild_id": "오디오 플레이어의 서버 ID",
        "crossfade": 10 // seconds
    }
}
```

### setAutoplay

```json5
{
    "op": "setAutoplay",
    "d": {
        "guild_id": "오디오 플레이어의 서버 ID",
        "autoplay": true
    }
}
```

### setFilter

```json5
{
    "op": "setFilter",
    "d": {
        "guild_id": "오디오 플레이어의 서버 ID",
        "filter": {
            // libavfilter 객체
        }
    }
}
```

### getSource

```json
{
    "op": "getSource",
    "d": {
        "guild_id": "오디오 플레이어의 서버 ID",
        "query": "검색할 문자"
    }
}
```

### loadSource

```json
{
    "op": "loadSource",
    "d": {
        "guild_id": "오디오 플레이어의 서버 ID",
        "query": "검색할 문자"
    }
}
```

### putSong

```json5
{
    "op": "putSource",
    "d": {
        "guild_id": "오디오 플레이어의 서버 ID",
        "source": {
            // Source 객체
        }
    }
}
```

### skip

```json5
{
    "op": "skip",
    "d": {
        "guild_id": "오디오 플레이어의 서버 ID",
        "offset": 1 // 건너뛸 소스 개수
    }
}
```

### seek

```json5
{
    "op": "seek",
    "d": {
        "guild_id": "오디오 플레이어의 서버 ID",
        "offset": 10 // 초
    }
}
```

### getQueue

```json
{
    "op": "getQueue",
    "d": {
        "guild_id": "오디오 플레이어의 서버 ID"
    }
}
```

### getState

```json
{
    "op": "getState",
    "d": {
        "guild_id": "오디오 플레이어의 서버 ID"
    }
}
```

### pause

```json
{
    "op": "pause",
    "d": {
        "guild_id": "오디오 플레이어의 서버 ID"
    }
}
```

### resume

```json
{
    "op": "resume",
    "d": {
        "guild_id": "오디오 플레이어의 서버 ID"
    }
}
```

### shuffle

```json
{
    "op": "shuffle",
    "d": {
        "guild_id": "오디오 플레이어의 서버 ID"
    }
}
```

### remove

```json5
{
    "op": "remove",
    "d": {
        "guild_id": "오디오 플레이어의 서버 ID",
        "index": 1 // 삭제할 소스 번호
    }
}
```

### requestSubtitle

`lang` 나 `url` 중 하나가 필요합니다.

디스코도는 `smi` 와 `srv1` 가 호환됩니다.

```json5
{
    "op": "requestSubtitle",
    "d": {
        "guild_id": "삭제할 소스 번호",
        "lang": "en",
        "url": "..."
    }
}
```

### VC_DESTROY

```json
{
    "op": "VC_DESTROY",
    "d": {
        "guild_id": "삭제할 소스 번호"
    }
}
```
